==> haskell-yesod-default-1.2.0-200-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-yesod-default.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: yesod-default
version: 1.2.0
id: yesod-default-1.2.0-39jpwKkgheNJozWiJvvDrR
key: yesod-default-1.2.0-39jpwKkgheNJozWiJvvDrR
license: MIT
maintainer: Patrick Brisbin <pbrisbin@gmail.com>
stability: Stable
homepage: http://www.yesodweb.com/
synopsis: Default config and main functions for your yesod application (deprecated)
description:
    Since version 1.2 of Yesod, this functionality is provided by the yesod package. This package is no longer needed.
    execution of your yesod application
category: Web, Yesod
author: Patrick Brisbin
exposed: True
indefinite: False
exposed-modules:
    Yesod.Default.Ignore
abi: 68eb5feb53ac1c22a4e9f610b7252369
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/yesod-default-1.2.0
library-dirs: /usr/lib/ghc-8.2.1/site-local/yesod-default-1.2.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.2.1/yesod-default-1.2.0
hs-libraries: HSyesod-default-1.2.0-39jpwKkgheNJozWiJvvDrR
depends:
    base-4.10.0.0 yesod-core-1.4.37-EBGkF6t8tgdJwj9XkY4HV0
abi-depends: base-4.10.0.0=835a16347ec1b210054efd02671c29ee
             yesod-core-1.4.37-EBGkF6t8tgdJwj9XkY4HV0=8aec100ebd97108f54bc594e98ad2291
haddock-interfaces: /usr/share/doc/haskell-yesod-default/html/yesod-default.haddock
haddock-html: /usr/share/doc/haskell-yesod-default/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-yesod-default-1.2.0-201-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-yesod-default.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: yesod-default
version: 1.2.0
id: yesod-default-1.2.0-51ZJY7q58mK2pXAHeB225B
key: yesod-default-1.2.0-51ZJY7q58mK2pXAHeB225B
license: MIT
maintainer: Patrick Brisbin <pbrisbin@gmail.com>
stability: Stable
homepage: http://www.yesodweb.com/
synopsis: Default config and main functions for your yesod application (deprecated)
description:
    Since version 1.2 of Yesod, this functionality is provided by the yesod package. This package is no longer needed.
    execution of your yesod application
category: Web, Yesod
author: Patrick Brisbin
exposed: True
indefinite: False
exposed-modules:
    Yesod.Default.Ignore
abi: c9210ed9a32714992196c8c686d0039c
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/yesod-default-1.2.0
library-dirs: /usr/lib/ghc-8.2.1/site-local/yesod-default-1.2.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.2.1/yesod-default-1.2.0
hs-libraries: HSyesod-default-1.2.0-51ZJY7q58mK2pXAHeB225B
depends:
    base-4.10.0.0 yesod-core-1.4.37-8at1q0UcqJ6LfszxkbB10K
abi-depends: base-4.10.0.0=835a16347ec1b210054efd02671c29ee
             yesod-core-1.4.37-8at1q0UcqJ6LfszxkbB10K=9717eb91fa58a044e07089bc3cd3174a
haddock-interfaces: /usr/share/doc/haskell-yesod-default/html/yesod-default.haddock
haddock-html: /usr/share/doc/haskell-yesod-default/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
